Code cleanup and minor fixes.
diff --git a/MPChartLib/src/com/github/mikephil/charting/charts/BarLineChartBase.java b/MPChartLib/src/com/github/mikephil/charting/charts/BarLineChartBase.java
index 463d900..8bb74c8 100644
--- a/MPChartLib/src/com/github/mikephil/charting/charts/BarLineChartBase.java
+++ b/MPChartLib/src/com/github/mikephil/charting/charts/BarLineChartBase.java
@@ -370,11 +370,11 @@
 
             // offsets for y-labels
             if (mAxisLeft.needsOffset()) {
-                offsetLeft += mAxisLeft.getRequiredWidthSpace(mAxisRendererLeft.getAxisPaint());
+                offsetLeft += mAxisLeft.getRequiredWidthSpace(mAxisRendererLeft.getPaintAxisLabels());
             }
 
             if (mAxisRight.needsOffset()) {
-                offsetRight += mAxisRight.getRequiredWidthSpace(mAxisRendererRight.getAxisPaint());
+                offsetRight += mAxisRight.getRequiredWidthSpace(mAxisRendererRight.getPaintAxisLabels());
             }
 
             float xlabelheight = mXAxis.mLabelHeight * 2f;
diff --git a/MPChartLib/src/com/github/mikephil/charting/charts/Chart.java b/MPChartLib/src/com/github/mikephil/charting/charts/Chart.java
index 45476c3..7db7e6d 100644
--- a/MPChartLib/src/com/github/mikephil/charting/charts/Chart.java
+++ b/MPChartLib/src/com/github/mikephil/charting/charts/Chart.java
@@ -12,7 +12,6 @@
 import android.graphics.Color;
 import android.graphics.Paint;
 import android.graphics.Paint.Align;
-import android.graphics.Paint.Style;
 import android.graphics.PointF;
 import android.graphics.RectF;
 import android.graphics.Typeface;
@@ -89,9 +88,6 @@
      */
     protected Paint mInfoPaint;
 
-    /** this is the paint object used for drawing the data onto the chart */
-    protected Paint mRenderPaint;
-
     /** description text that appears in the bottom right corner of the chart */
     protected String mDescription = "Description";
 
@@ -193,9 +189,6 @@
 
         mLegendRenderer = new LegendRenderer(mViewPortHandler, mLegend);
 
-        mRenderPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
-        mRenderPaint.setStyle(Style.FILL);
-
         mDescPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
         mDescPaint.setColor(Color.BLACK);
         mDescPaint.setTextAlign(Align.RIGHT);
@@ -1039,9 +1032,6 @@
     /** paint for the text in the middle of the pie chart */
     public static final int PAINT_CENTER_TEXT = 14;
 
-    /** paint used for all rendering processes */
-    public static final int PAINT_RENDER = 17;
-
     /** paint used for the legend */
     public static final int PAINT_LEGEND_LABEL = 18;
 
@@ -1062,9 +1052,6 @@
             case PAINT_DESCRIPTION:
                 mDescPaint = p;
                 break;
-            case PAINT_RENDER:
-                mRenderPaint = p;
-                break;
         }
     }
 
@@ -1080,8 +1067,6 @@
                 return mInfoPaint;
             case PAINT_DESCRIPTION:
                 return mDescPaint;
-            case PAINT_RENDER:
-                return mRenderPaint;
         }
 
         return null;
@@ -1108,33 +1093,6 @@
         mDrawMarkerViews = enabled;
     }
 
-    // /**
-    // * sets the draw color for the value paint object
-    // *
-    // * @param color
-    // */
-    // public void setValueTextColor(int color) {
-    // mRenderer.getPaintValues().setColor(color);
-    // }
-    //
-    // /**
-    // * Sets the font size of the values that are drawn inside the chart.
-    // *
-    // * @param size
-    // */
-    // public void setValueTextSize(float size) {
-    // mRenderer.getPaintValues().setTextSize(Utils.convertDpToPixel(size));
-    // }
-    //
-    // /**
-    // * sets a typeface for the value-paint
-    // *
-    // * @param t
-    // */
-    // public void setValueTypeface(Typeface t) {
-    // mRenderer.getPaintValues().setTypeface(t);
-    // }
-
     /**
      * returns the x-value at the given index
      *
@@ -1390,11 +1348,6 @@
     }
 
     @Override
-    public View getChartView() {
-        return this;
-    }
-
-    @Override
     public PointF getCenterOfView() {
         return getCenter();
     }
diff --git a/MPChartLib/src/com/github/mikephil/charting/charts/HorizontalBarChart.java b/MPChartLib/src/com/github/mikephil/charting/charts/HorizontalBarChart.java
index 7499751..3f3a525 100644
--- a/MPChartLib/src/com/github/mikephil/charting/charts/HorizontalBarChart.java
+++ b/MPChartLib/src/com/github/mikephil/charting/charts/HorizontalBarChart.java
@@ -82,11 +82,11 @@
 
         // offsets for y-labels
         if (mAxisLeft.needsOffset()) {
-            offsetTop += mAxisLeft.getRequiredHeightSpace(mAxisRendererLeft.getAxisPaint());
+            offsetTop += mAxisLeft.getRequiredHeightSpace(mAxisRendererLeft.getPaintAxisLabels());
         }
 
         if (mAxisRight.needsOffset()) {
-            offsetBottom += mAxisRight.getRequiredHeightSpace(mAxisRendererRight.getAxisPaint());
+            offsetBottom += mAxisRight.getRequiredHeightSpace(mAxisRendererRight.getPaintAxisLabels());
         }
 
         float xlabelwidth = mXAxis.mLabelWidth;
diff --git a/MPChartLib/src/com/github/mikephil/charting/interfaces/ChartInterface.java b/MPChartLib/src/com/github/mikephil/charting/interfaces/ChartInterface.java
index 93649d9..fcacaee 100644
--- a/MPChartLib/src/com/github/mikephil/charting/interfaces/ChartInterface.java
+++ b/MPChartLib/src/com/github/mikephil/charting/interfaces/ChartInterface.java
@@ -3,7 +3,6 @@
 
 import android.graphics.PointF;
 import android.graphics.RectF;
-import android.view.View;
 
 import com.github.mikephil.charting.utils.ValueFormatter;
 
@@ -32,9 +31,6 @@
     public PointF getCenterOffsets();
 
     public RectF getContentRect();
-
-    public View getChartView();
-
+    
     public ValueFormatter getDefaultValueFormatter();
-
 }
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/DataRenderer.java b/MPChartLib/src/com/github/mikephil/charting/renderer/DataRenderer.java
index 59f2a1a..6f44acb 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/DataRenderer.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/DataRenderer.java
@@ -72,6 +72,15 @@
     }
 
     /**
+     * Returns the Paint object used for rendering.
+     * 
+     * @return
+     */
+    public Paint getPaintRender() {
+        return mRenderPaint;
+    }
+
+    /**
      * Applies the required styling (provided by the DataSet) to the value-paint
      * object.
      * 
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/LegendRenderer.java b/MPChartLib/src/com/github/mikephil/charting/renderer/LegendRenderer.java
index d59e0fc..a4d5370 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/LegendRenderer.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/LegendRenderer.java
@@ -3,8 +3,8 @@
 
 import android.graphics.Canvas;
 import android.graphics.Paint;
-import android.graphics.Typeface;
 import android.graphics.Paint.Align;
+import android.graphics.Typeface;
 
 import com.github.mikephil.charting.components.Legend;
 import com.github.mikephil.charting.data.BarDataSet;
@@ -165,9 +165,6 @@
         Legend.LegendDirection direction = mLegend.getDirection();
         float formSize = mLegend.getFormSize();
 
-        // space between text and shape/form of entry
-        float formTextSpaceAndForm = formToTextSpace + formSize;
-
         // space between the entries
         float stackSpace = mLegend.getStackSpace();
 
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRenderer.java b/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRenderer.java
index 93fa067..9c6f74c 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRenderer.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRenderer.java
@@ -22,15 +22,15 @@
 
         this.mXAxis = xAxis;
 
-        mAxisPaint.setColor(Color.BLACK);
-        mAxisPaint.setTextAlign(Align.CENTER);
-        mAxisPaint.setTextSize(Utils.convertDpToPixel(10f));
+        mAxisLabelPaint.setColor(Color.BLACK);
+        mAxisLabelPaint.setTextAlign(Align.CENTER);
+        mAxisLabelPaint.setTextSize(Utils.convertDpToPixel(10f));
     }
 
     public void computeAxis(float xValAverageLength, List<String> xValues) {
 
-        mAxisPaint.setTypeface(mXAxis.getTypeface());
-        mAxisPaint.setTextSize(mXAxis.getTextSize());
+        mAxisLabelPaint.setTypeface(mXAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mXAxis.getTextSize());
 
         StringBuffer a = new StringBuffer();
 
@@ -41,8 +41,8 @@
             a.append("h");
         }
 
-        mXAxis.mLabelWidth = Utils.calcTextWidth(mAxisPaint, a.toString());
-        mXAxis.mLabelHeight = Utils.calcTextHeight(mAxisPaint, "Q");
+        mXAxis.mLabelWidth = Utils.calcTextWidth(mAxisLabelPaint, a.toString());
+        mXAxis.mLabelHeight = Utils.calcTextHeight(mAxisLabelPaint, "Q");
         mXAxis.setValues(xValues);
     }
 
@@ -54,9 +54,9 @@
 
         float yoffset = Utils.convertDpToPixel(4f);
 
-        mAxisPaint.setTypeface(mXAxis.getTypeface());
-        mAxisPaint.setTextSize(mXAxis.getTextSize());
-        mAxisPaint.setColor(mXAxis.getTextColor());
+        mAxisLabelPaint.setTypeface(mXAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mXAxis.getTextSize());
+        mAxisLabelPaint.setColor(mXAxis.getTextColor());
 
         if (mXAxis.getPosition() == XAxisPosition.TOP) {
 
@@ -144,7 +144,7 @@
 
                     // avoid clipping of the last
                     if (i == mXAxis.getValues().size() - 1 && mXAxis.getValues().size() > 1) {
-                        float width = Utils.calcTextWidth(mAxisPaint, label);
+                        float width = Utils.calcTextWidth(mAxisLabelPaint, label);
 
                         if (width > mViewPortHandler.offsetRight() * 2
                                 && position[0] + width > mViewPortHandler.getChartWidth())
@@ -153,14 +153,14 @@
                         // avoid clipping of the first
                     } else if (i == 0) {
 
-                        float width = Utils.calcTextWidth(mAxisPaint, label);
+                        float width = Utils.calcTextWidth(mAxisLabelPaint, label);
                         position[0] += width / 2;
                     }
                 }
 
                 c.drawText(label, position[0],
                         pos,
-                        mAxisPaint);
+                        mAxisLabelPaint);
             }
         }
     }
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererBarChart.java b/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererBarChart.java
index 99b2d80..f9fc0cd 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererBarChart.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererBarChart.java
@@ -64,7 +64,7 @@
 
                     // avoid clipping of the last
                     if (i == mXAxis.getValues().size() - 1) {
-                        float width = Utils.calcTextWidth(mAxisPaint, label);
+                        float width = Utils.calcTextWidth(mAxisLabelPaint, label);
 
                         if (width > mViewPortHandler.offsetRight() * 2
                                 && position[0] + width > mViewPortHandler.getChartWidth())
@@ -73,14 +73,14 @@
                         // avoid clipping of the first
                     } else if (i == 0) {
 
-                        float width = Utils.calcTextWidth(mAxisPaint, label);
+                        float width = Utils.calcTextWidth(mAxisLabelPaint, label);
                         position[0] += width / 2;
                     }
                 }
 
                 c.drawText(label, position[0],
                         pos,
-                        mAxisPaint);
+                        mAxisLabelPaint);
             }
         }
     }
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererHorizontalBarChart.java b/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererHorizontalBarChart.java
index aa34958..cadc5e0 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererHorizontalBarChart.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererHorizontalBarChart.java
@@ -24,13 +24,13 @@
     @Override
     public void computeAxis(float xValAverageLength, List<String> xValues) {
         
-        mAxisPaint.setTypeface(mXAxis.getTypeface());
-        mAxisPaint.setTextSize(mXAxis.getTextSize());
+        mAxisLabelPaint.setTypeface(mXAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mXAxis.getTextSize());
         mXAxis.setValues(xValues);
 
         String longest = mXAxis.getLongestLabel();
-        mXAxis.mLabelWidth = (int) (Utils.calcTextWidth(mAxisPaint, longest) + mXAxis.getXOffset() * 3.5f);
-        mXAxis.mLabelHeight = Utils.calcTextHeight(mAxisPaint, longest);
+        mXAxis.mLabelWidth = (int) (Utils.calcTextWidth(mAxisLabelPaint, longest) + mXAxis.getXOffset() * 3.5f);
+        mXAxis.mLabelHeight = Utils.calcTextHeight(mAxisLabelPaint, longest);
     }
 
     @Override
@@ -41,28 +41,28 @@
 
         float xoffset = mXAxis.getXOffset();
 
-        mAxisPaint.setTypeface(mXAxis.getTypeface());
-        mAxisPaint.setTextSize(mXAxis.getTextSize());
-        mAxisPaint.setColor(mXAxis.getTextColor());
+        mAxisLabelPaint.setTypeface(mXAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mXAxis.getTextSize());
+        mAxisLabelPaint.setColor(mXAxis.getTextColor());
 
         if (mXAxis.getPosition() == XAxisPosition.TOP) {
 
-            mAxisPaint.setTextAlign(Align.LEFT);
+            mAxisLabelPaint.setTextAlign(Align.LEFT);
             drawLabels(c, mViewPortHandler.contentRight() + xoffset);
 
         } else if (mXAxis.getPosition() == XAxisPosition.BOTTOM) {
 
-            mAxisPaint.setTextAlign(Align.RIGHT);
+            mAxisLabelPaint.setTextAlign(Align.RIGHT);
             drawLabels(c, mViewPortHandler.contentLeft() - xoffset);
 
         } else if (mXAxis.getPosition() == XAxisPosition.BOTTOM_INSIDE) {
 
-            mAxisPaint.setTextAlign(Align.LEFT);
+            mAxisLabelPaint.setTextAlign(Align.LEFT);
             drawLabels(c, mViewPortHandler.contentLeft() + xoffset);
 
         } else if (mXAxis.getPosition() == XAxisPosition.TOP_INSIDE) {
 
-            mAxisPaint.setTextAlign(Align.RIGHT);
+            mAxisLabelPaint.setTextAlign(Align.RIGHT);
             drawLabels(c, mViewPortHandler.contentRight() - xoffset);
 
         } else { // BOTH SIDED
@@ -104,7 +104,7 @@
 
                 String label = mXAxis.getValues().get(i);
                 c.drawText(label, pos, position[1] + mXAxis.mLabelHeight / 2f,
-                        mAxisPaint);
+                        mAxisLabelPaint);
             }
         }
     }
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererRadarChart.java b/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererRadarChart.java
index d3e277c..3ffecd6 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererRadarChart.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/XAxisRendererRadarChart.java
@@ -25,9 +25,9 @@
         if (!mXAxis.isEnabled() || !mXAxis.isDrawLabelsEnabled())
             return;
 
-        mAxisPaint.setTypeface(mXAxis.getTypeface());
-        mAxisPaint.setTextSize(mXAxis.getTextSize());
-        mAxisPaint.setColor(mXAxis.getTextColor());
+        mAxisLabelPaint.setTypeface(mXAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mXAxis.getTextSize());
+        mAxisLabelPaint.setColor(mXAxis.getTextColor());
 
         float sliceangle = mChart.getSliceAngle();
 
@@ -46,7 +46,7 @@
             PointF p = Utils.getPosition(center, mChart.getYRange() * factor
                     + mXAxis.mLabelWidth / 2f, angle);
 
-            c.drawText(text, p.x, p.y + mXAxis.mLabelHeight / 2f, mAxisPaint);
+            c.drawText(text, p.x, p.y + mXAxis.mLabelHeight / 2f, mAxisLabelPaint);
         }
     }
 }
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRenderer.java b/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRenderer.java
index aec666b..dca9275 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRenderer.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRenderer.java
@@ -31,8 +31,8 @@
 
         this.mYAxis = yAxis;
 
-        mAxisPaint.setColor(Color.BLACK);
-        mAxisPaint.setTextSize(Utils.convertDpToPixel(10f));
+        mAxisLabelPaint.setColor(Color.BLACK);
+        mAxisLabelPaint.setTextSize(Utils.convertDpToPixel(10f));
 
         mLimitLinePaint = new Paint(Paint.ANTI_ALIAS_FLAG);
         mLimitLinePaint.setStyle(Paint.Style.FILL_AND_STROKE);
@@ -161,12 +161,12 @@
 
         mTrans.pointValuesToPixel(positions);
 
-        mAxisPaint.setTypeface(mYAxis.getTypeface());
-        mAxisPaint.setTextSize(mYAxis.getTextSize());
-        mAxisPaint.setColor(mYAxis.getTextColor());
+        mAxisLabelPaint.setTypeface(mYAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mYAxis.getTextSize());
+        mAxisLabelPaint.setColor(mYAxis.getTextColor());
 
         float xoffset = mYAxis.getXOffset();
-        float yoffset = Utils.calcTextHeight(mAxisPaint, "A") / 2.5f;
+        float yoffset = Utils.calcTextHeight(mAxisLabelPaint, "A") / 2.5f;
 
         AxisDependency dependency = mYAxis.getAxisDependency();
         YAxisLabelPosition labelPosition = mYAxis.getLabelPosition();
@@ -176,20 +176,20 @@
         if (dependency == AxisDependency.LEFT) {
 
             if (labelPosition == YAxisLabelPosition.OUTSIDE_CHART) {
-                mAxisPaint.setTextAlign(Align.RIGHT);
+                mAxisLabelPaint.setTextAlign(Align.RIGHT);
                 xPos = mViewPortHandler.offsetLeft() - xoffset;
             } else {
-                mAxisPaint.setTextAlign(Align.LEFT);
+                mAxisLabelPaint.setTextAlign(Align.LEFT);
                 xPos = mViewPortHandler.offsetLeft() + xoffset;
             }
 
         } else {
 
             if (labelPosition == YAxisLabelPosition.OUTSIDE_CHART) {
-                mAxisPaint.setTextAlign(Align.LEFT);
+                mAxisLabelPaint.setTextAlign(Align.LEFT);
                 xPos = mViewPortHandler.contentRight() + xoffset;
             } else {
-                mAxisPaint.setTextAlign(Align.RIGHT);
+                mAxisLabelPaint.setTextAlign(Align.RIGHT);
                 xPos = mViewPortHandler.contentRight() - xoffset;
             }
         }
@@ -233,7 +233,7 @@
             if (!mYAxis.isDrawTopYLabelEntryEnabled() && i >= mYAxis.mEntryCount - 1)
                 return;
 
-            c.drawText(text, fixedPosition, positions[i * 2 + 1] + offset, mAxisPaint);
+            c.drawText(text, fixedPosition, positions[i * 2 + 1] + offset, mAxisLabelPaint);
         }
     }
 
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRendererHorizontalBarChart.java b/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRendererHorizontalBarChart.java
index 7018e72..b23aebe 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRendererHorizontalBarChart.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRendererHorizontalBarChart.java
@@ -79,12 +79,12 @@
 
         mTrans.pointValuesToPixel(positions);
 
-        mAxisPaint.setTypeface(mYAxis.getTypeface());
-        mAxisPaint.setTextSize(mYAxis.getTextSize());
-        mAxisPaint.setColor(mYAxis.getTextColor());
-        mAxisPaint.setTextAlign(Align.CENTER);
+        mAxisLabelPaint.setTypeface(mYAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mYAxis.getTextSize());
+        mAxisLabelPaint.setColor(mYAxis.getTextColor());
+        mAxisLabelPaint.setTextAlign(Align.CENTER);
 
-        float yoffset = Utils.calcTextHeight(mAxisPaint, "A") + mYAxis.getYOffset();
+        float yoffset = Utils.calcTextHeight(mAxisLabelPaint, "A") + mYAxis.getYOffset();
 
         AxisDependency dependency = mYAxis.getAxisDependency();
         YAxisLabelPosition labelPosition = mYAxis.getLabelPosition();
@@ -144,9 +144,9 @@
     @Override
     protected void drawYLabels(Canvas c, float fixedPosition, float[] positions, float offset) {
         
-        mAxisPaint.setTypeface(mYAxis.getTypeface());
-        mAxisPaint.setTextSize(mYAxis.getTextSize());
-        mAxisPaint.setColor(mYAxis.getTextColor());
+        mAxisLabelPaint.setTypeface(mYAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mYAxis.getTextSize());
+        mAxisLabelPaint.setColor(mYAxis.getTextColor());
 
         for (int i = 0; i < mYAxis.mEntryCount; i++) {
 
@@ -155,7 +155,7 @@
             if (!mYAxis.isDrawTopYLabelEntryEnabled() && i >= mYAxis.mEntryCount - 1)
                 return;
 
-            c.drawText(text, positions[i * 2], fixedPosition - offset, mAxisPaint);
+            c.drawText(text, positions[i * 2], fixedPosition - offset, mAxisLabelPaint);
         }
     }
 
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRendererRadarChart.java b/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRendererRadarChart.java
index 974a305..0c7a46c 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRendererRadarChart.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/YAxisRendererRadarChart.java
@@ -103,9 +103,9 @@
         if (!mYAxis.isEnabled() || !mYAxis.isDrawLabelsEnabled())
             return;
 
-        mAxisPaint.setTypeface(mYAxis.getTypeface());
-        mAxisPaint.setTextSize(mYAxis.getTextSize());
-        mAxisPaint.setColor(mYAxis.getTextColor());
+        mAxisLabelPaint.setTypeface(mYAxis.getTypeface());
+        mAxisLabelPaint.setTextSize(mYAxis.getTextSize());
+        mAxisLabelPaint.setColor(mYAxis.getTextColor());
 
         PointF center = mChart.getCenterOffsets();
         float factor = mChart.getFactor();
@@ -123,7 +123,7 @@
 
             String label = mYAxis.getFormattedLabel(j);
 
-            c.drawText(label, p.x + 10, p.y, mAxisPaint);
+            c.drawText(label, p.x + 10, p.y, mAxisLabelPaint);
         }
     }
 
diff --git a/MPChartLib/src/com/github/mikephil/charting/utils/ViewPortHandler.java b/MPChartLib/src/com/github/mikephil/charting/utils/ViewPortHandler.java
index a362631..324bc8b 100644
--- a/MPChartLib/src/com/github/mikephil/charting/utils/ViewPortHandler.java
+++ b/MPChartLib/src/com/github/mikephil/charting/utils/ViewPortHandler.java
@@ -5,7 +5,7 @@
 import android.graphics.PointF;
 import android.graphics.RectF;
 
-import com.github.mikephil.charting.interfaces.ChartInterface;
+import com.github.mikephil.charting.charts.Chart;
 
 public class ViewPortHandler {
 
@@ -207,7 +207,7 @@
      * @param chart
      * @return save
      */
-    public synchronized void centerViewPort(final float[] transformedPts, final ChartInterface chart) {
+    public synchronized void centerViewPort(final float[] transformedPts, final Chart<?> chart) {
 
         Matrix save = new Matrix();
         save.set(mMatrixTouch);
@@ -244,14 +244,14 @@
      * @param newMatrix
      * @return
      */
-    public Matrix refresh(Matrix newMatrix, ChartInterface chart, boolean invalidate) {
+    public Matrix refresh(Matrix newMatrix, Chart<?> chart, boolean invalidate) {
 
         mMatrixTouch.set(newMatrix);
 
         // make sure scale and translation are within their bounds
         limitTransAndScale(mMatrixTouch, mContentRect);
 
-        chart.getChartView().invalidate();
+        chart.invalidate();
 
         newMatrix.set(mMatrixTouch);
         return newMatrix;
diff --git a/MPChartLib/src/com/github/mikephil/charting/renderer/AxisRenderer.java b/MPChartLib/src/com/github/mikephil/charting/renderer/AxisRenderer.java
index a9f6c22..df5b49f 100644
--- a/MPChartLib/src/com/github/mikephil/charting/renderer/AxisRenderer.java
+++ b/MPChartLib/src/com/github/mikephil/charting/renderer/AxisRenderer.java
@@ -9,6 +9,11 @@
 import com.github.mikephil.charting.utils.Transformer;
 import com.github.mikephil.charting.utils.ViewPortHandler;
 
+/**
+ * Baseclass of all axis renderers.
+ * 
+ * @author Philipp Jahoda
+ */
 public abstract class AxisRenderer extends Renderer {
 
     protected Transformer mTrans;
@@ -17,7 +22,7 @@
     protected Paint mGridPaint;
 
     /** paint for the x-label values */
-    protected Paint mAxisPaint;    
+    protected Paint mAxisLabelPaint;
 
     /** paint for the line surrounding the chart */
     protected Paint mAxisLinePaint;
@@ -27,14 +32,14 @@
 
         this.mTrans = trans;
 
-        mAxisPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
+        mAxisLabelPaint = new Paint(Paint.ANTI_ALIAS_FLAG);
 
         mGridPaint = new Paint();
         mGridPaint.setColor(Color.GRAY);
         mGridPaint.setStrokeWidth(1f);
         mGridPaint.setStyle(Style.STROKE);
         mGridPaint.setAlpha(90);
-        
+
         mAxisLinePaint = new Paint();
         mAxisLinePaint.setColor(Color.BLACK);
         mAxisLinePaint.setStrokeWidth(1f);
@@ -42,12 +47,32 @@
     }
 
     /**
      * Returns the Paint object used for drawing the axis.
      * 
      * @return
      */
-    public Paint getAxisPaint() {
-        return mAxisPaint;
+    public Paint getPaintAxisLabels() {
+        return mAxisLabelPaint;
+    }
+
+    /**
+     * Returns the Paint object that is used for drawing the grid-lines of the
+     * axis.
+     * 
+     * @return
+     */
+    public Paint getPaintGrid() {
+        return mGridPaint;
+    }
+
+    /**
+     * Returns the Paint object that is used for drawing the axis-line that goes
+     * alongside the axis.
+     * 
+     * @return
+     */
+    public Paint getPaintAxisLine() {
+        return mAxisLinePaint;
     }
 
     /**
@@ -42,12 +47,32 @@
 
     /**
-     * Returns the Paint object used for drawing the axis.
+     * Returns the Paint object used for drawing the axis (labels).
      * 
      * @return